Struct SpawnError
pub struct SpawnError {
_priv: (),
}Expand description
An error that occurred during spawning.
Fields
_priv: ()Implementations
impl SpawnError
impl SpawnError
pub fn shutdown() -> SpawnError
pub fn shutdown() -> SpawnError
Spawning failed because the executor has been shut down.
pub fn is_shutdown(&self) -> bool
pub fn is_shutdown(&self) -> bool
Check whether spawning failed to the executor being shut down.